==> haskell-split-0.2.3.3-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-split.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: split
version: 0.2.3.3
id: split-0.2.3.3-IplalSEyA8cIcP7jnQyYs9
key: split-0.2.3.3-IplalSEyA8cIcP7jnQyYs9
license: BSD-3-Clause
copyright: (c) Brent Yorgey, Louis Wasserman 2008-2012
maintainer: byorgey@gmail.com
author: Brent Yorgey
stability: stable
synopsis: Combinator library for splitting lists.
description:
    A collection of various methods for splitting
    lists into parts, akin to the \"split\" function
    found in several mainstream languages. Here is
    its tale:
    .
    Once upon a time the standard "Data.List" module
    held no function for splitting a list into parts
    according to a delimiter.  Many a brave
    lambda-knight strove to add such a function, but
    their striving was in vain, for Lo, the Supreme
    Council fell to bickering amongst themselves what
    was to be the essential nature of the One True
    Function which could cleave a list in twain (or
    thrain, or any required number of parts).
    .
    And thus came to pass the split package,
    comprising divers functions for splitting a list
    asunder, each according to its nature.  And the
    Supreme Council had no longer any grounds for
    argument, for the favored method of each was
    contained therein.
    .
    To get started, see the "Data.List.Split" module.
category: List
abi: 26b4b58799c0d1273f607be327882ed1
exposed: True
exposed-modules:
    Data.List.Split Data.List.Split.Internals
import-dirs: /usr/lib/ghc-8.6.3/site-local/split-0.2.3.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/split-0.2.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/split-0.2.3.3
hs-libraries: HSsplit-0.2.3.3-IplalSEyA8cIcP7jnQyYs9
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-split/html/split.haddock
haddock-html: /usr/share/doc/haskell-split/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-split-0.2.3.3-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-split.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: split
version: 0.2.3.3
id: split-0.2.3.3-DmDMlgWSMW26OczFIiZ5Gr
key: split-0.2.3.3-DmDMlgWSMW26OczFIiZ5Gr
license: BSD-3-Clause
copyright: (c) Brent Yorgey, Louis Wasserman 2008-2012
maintainer: byorgey@gmail.com
author: Brent Yorgey
stability: stable
synopsis: Combinator library for splitting lists.
description:
    A collection of various methods for splitting
    lists into parts, akin to the \"split\" function
    found in several mainstream languages. Here is
    its tale:
    .
    Once upon a time the standard "Data.List" module
    held no function for splitting a list into parts
    according to a delimiter.  Many a brave
    lambda-knight strove to add such a function, but
    their striving was in vain, for Lo, the Supreme
    Council fell to bickering amongst themselves what
    was to be the essential nature of the One True
    Function which could cleave a list in twain (or
    thrain, or any required number of parts).
    .
    And thus came to pass the split package,
    comprising divers functions for splitting a list
    asunder, each according to its nature.  And the
    Supreme Council had no longer any grounds for
    argument, for the favored method of each was
    contained therein.
    .
    To get started, see the "Data.List.Split" module.
category: List
abi: b4c457d6d34e7b0a9aa22e35877810dc
exposed: True
exposed-modules:
    Data.List.Split Data.List.Split.Internals
import-dirs: /usr/lib/ghc-8.6.4/site-local/split-0.2.3.3
library-dirs: /usr/lib/ghc-8.6.4/site-local/split-0.2.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/split-0.2.3.3
hs-libraries: HSsplit-0.2.3.3-DmDMlgWSMW26OczFIiZ5Gr
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-split/html/split.haddock
haddock-html: /usr/share/doc/haskell-split/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
